import { BroadcastEvent, WidgetData, WidgetParams, WidgetTheme } from '@widget-js/core';
import { ComputedRef, Ref, UnwrapRef } from 'vue';
import { RemoveableRef } from '@vueuse/core';
import { UseDefaultOverlapContextMenuOption, UseWidgetParamsOptions, UseWidgetThemeOptions } from '.';

interface UseWidgetOptions<T extends WidgetData> extends UseWidgetParamsOptions, UseWidgetThemeOptions {
    onDataLoaded?: (data: T | undefined, initialLoad: boolean) => void;
    defaultData?: UnwrapRef<T>;
    /**
     * 是否忽略组件id，只通过组件名获取数据
     */
    loadDataByWidgetName?: boolean;
    /**
     * 组件id，如果不传默认使用WidgetParams里的id
     */
    widgetId?: string;
    /**
     * 组件名，如果不传默认使用WidgetParams里的name
     */
    widgetName?: string;
    defaultOverlapMenu?: boolean | UseDefaultOverlapContextMenuOption;
    useBroadcastEvent?: string[];
    onBroadcastEvent?: (broadcastEvent: BroadcastEvent) => void;
}
interface UseWidgetReturn<T extends WidgetData> {
    widgetParams: WidgetParams;
    widgetData: Ref<UnwrapRef<T>>;
    widgetTheme: RemoveableRef<WidgetTheme>;
    dataLoaded: Ref<boolean>;
    sizeStyle: ComputedRef<{
        width: string;
        height: string;
    }>;
    save: (saveOptions?: SaveOptions) => Promise<void>;
}
interface SaveOptions {
    closeWindow?: boolean;
    sendBroadcast?: boolean;
}
/**
 * @deprecated
 * @param Type
 * @param options
 */
export declare function useWidgetData<T extends WidgetData>(Type: {
    new (name: string, id?: string): T;
}, options?: UseWidgetOptions<T>): UseWidgetReturn<T>;
export {};
//# sourceMappingURL=useWidgetData.d.ts.map